@@ -68,6 +68,7 @@ pass_config = click.make_pass_decorator(Config, ensure=True)
 @click.group(cls=AliasedGroup)
 @click.option("-f", "--force", is_flag=True)
 @click.option("-v", "--verbose", is_flag=True)
+@click.option("--version", is_flag=True)
 @click.option(
     "-xs",
     "--restrict-setting",
@@ -91,6 +92,7 @@ def cli(
     restrict_setting,
     restrict_docker_compose,
     chdir,
+    version,
 ):
     config.force = force
     config.verbose = verbose
@@ -176,12 +178,38 @@ def completion(execute):
         ):
             content += [f"\n{line}\n"]
             click.secho(
-                f"Inserted successfully\n{line}"
-                "\n\nPlease restart you shell."
-                )
-            rc_file.write_text('\n'.join(content))
+                f"Inserted successfully\n{line}" "\n\nPlease restart you shell."
+            )
+            rc_file.write_text("\n".join(content))
         else:
             click.secho("Nothing done - already existed.")
     else:
-        click.secho("\n\n" f"Insert into {rc_file}\n\n" f"echo '{line}' >> {rc_file}" "\n\n")
+        click.secho(
+            "\n\n" f"Insert into {rc_file}\n\n" f"echo '{line}' >> {rc_file}" "\n\n"
+        )
     sys.exit(0)
+
+
+@cli.command()
+@pass_config
+def version(config):
+    from .tools import _get_version
+
+    version = _get_version()
+
+    images_sha = subprocess.check_output(
+        ["git", "log", "-n1", "--format=%H"], encoding="utf8", cwd=config.dirs["images"]
+    ).strip()
+    images_branch = subprocess.check_output(
+        ["git", "rev-parse", "--abbrev-ref", "HEAD"],
+        encoding="utf8",
+        cwd=config.dirs["images"],
+    ).strip()
+    click.secho(
+        (
+            f"Wodoo Version:    {version}\n"
+            f"Images SHA:       {images_sha}\n"
+            f"Images Branch:    {images_branch}\n"
+        ),
+        fg="yellow",
+    )
