@@ -1,4 +1,6 @@
 import json
+import tempfile
+import shutil
 from pathlib import Path
 
 class ProgramSettings(object):
@@ -8,12 +10,15 @@ class ProgramSettings(object):
     def get(self, name, default_value=None):
         if not self.filename.exists():
             self.filename.write_text("{}")
-        data = json.loads(self.filename.read_text() or "{}")
+        data = json.loads(self.filename.read_text().strip() or "{}")
         return data.get(name, default_value)
 
     def set(self, name, value):
         if isinstance(value, Path):
             value = str(value)
-        data = json.loads(self.filename.read_text() or "{}")
+        data = json.loads(self.filename.read_text().strip() or "{}")
         data[name] = value
-        self.filename.write_text(json.dumps(data))
+        file = Path(tempfile.mktemp(suffix='.'))
+        file.write_text(json.dumps(data))
+        # concurrency support
+        shutil.move(file, self.filename)
